==> kjy-base-api-0.0.65-login3-20211129.093104-1-sources.jar: cn/com/duiba/kjy/base/api/utils/StringUtil.java <==
package cn.com.duiba.kjy.base.api.utils;

import cn.com.duiba.kjy.base.api.constant.DefaultConstant;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author liuchao1
 * @version 1.0
 * @date 2020-09-08 09:51
 */
public class StringUtil {

    private StringUtil() {
        //to do something
    }

    /**
     * 手机号匹配表达式
     */
    private static final Pattern PHONE_PATTERN = Pattern.compile("(1|861)((3[0-9])|(5[^4,\\D])|(8[0,5-9]))\\d{8}$*");

    /**
     * 字符串脱敏，只保留前后位的字符，中间字符全部替换成*
     * @param str 需要处理的字符串
     * @param prefix 前面保留位数
     * @param suffix 后面保留位数
     * @param onlyOne 是否只使用一个*脱敏，true：只有一个* false：有多少个字符需要脱敏就有多少*
     * @return 处理过后的字符串
     */
    public static String masking(String str, int prefix, int suffix, boolean onlyOne){

        //如果字符串为空字符
        if (StringUtils.isBlank(str)){
            return str;
        }

        //字符串长度小于等于需要保留的总位数，直接返回原字符串
        int temp = prefix + suffix;
        int length = StringUtils.length(str);
        if (length <= temp){
            return str;
        }
        StringBuilder builder = new StringBuilder(str.substring(0, prefix));

        int needSize = onlyOne ? 1 : length - temp;
        for (int j = 0; j < needSize; j++) {
            builder.append(DefaultConstant.ASTERISK);
        }
        builder.append(str, length - suffix, length);
        return builder.toString();
    }

    /**
     * 获取字符串中包含的手机号
     * @param str 字符串
     * @return 手机号集合
     */
    public static List<String> getPhoneNum(String str) {

        List<String> result = new ArrayList<>(4);

        if (str == null || str.length() <= 0) {
            return result;
        }

        Matcher matcher = PHONE_PATTERN.matcher(str);
        while (matcher.find()) {
            result.add(matcher.group());
        }

        return result;
    }

    /**
     * 日志打印脱敏手机号 格式：111*1111
     * @param phone 手机号
     * @return 脱敏后的字符串
     */
    public static String maskingPhoneForLog(String phone) {
        return masking(phone, 3, 4, true);
    }

    /**
     * 脱敏手机号 格式：111****1111
     * @param phone 手机号
     * @return 脱敏后的字符串
     */
    public static String maskingPhone(String phone) {
        return masking(phone, 3, 4, false);
    }

    /**
     * 从字符换里边配置出所有的手机号，并把手机号脱敏
     * @param str 需要处理的字符串
     * @param onlyOne 是否只需要一个*脱敏
     * @return 手机号脱敏后的字符串
     */
    public static String maskingAllPhone(String str, boolean onlyOne){
        if (StringUtils.isBlank(str)){
            return str;
        }

        List<String> list = StringUtil.getPhoneNum(str);
        if (CollectionUtils.isEmpty(list)){
            return str;
        }

        for (String s : list) {
            str = str.replaceAll(s, StringUtil.masking(s, 3, 4, onlyOne));
        }

        return str;
    }

    /**
     * 若字符串长度大于maxLength，则修剪
     * @param str 字符串
     * @param maxLength 最大长度
     * @return 前maxLength长度字符串
     */
    public static String subStringIfAbsent(String str, int maxLength) {
        if (str == null || str.isEmpty()) {
            return str;
        }
        if (str.length() <= maxLength) {
            return str;
        }
        return str.substring(0, maxLength);
    }
}

==> kjy-base-api-0.2.0-login-20220221.090811-1-sources.jar: cn/com/duiba/kjy/base/api/utils/StringUtil.java <==
package cn.com.duiba.kjy.base.api.utils;

import cn.com.duiba.kjy.base.api.constant.DefaultConstant;
import cn.com.duiba.wolf.utils.NumberUtils;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Objects;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import java.util.stream.Collectors;

/**
 * @author liuchao1
 * @version 1.0
 * @date 2020-09-08 09:51
 */
public class StringUtil {

    private StringUtil() {
        //to do something
    }

    /**
     * 手机号匹配表达式
     */
    private static final Pattern PHONE_PATTERN = Pattern.compile("(1|861)((3[0-9])|(5[^4,\\D])|(8[0,5-9]))\\d{8}$*");

    /**
     * 字符串脱敏，只保留前后位的字符，中间字符全部替换成*
     * @param str 需要处理的字符串
     * @param prefix 前面保留位数
     * @param suffix 后面保留位数
     * @param onlyOne 是否只使用一个*脱敏，true：只有一个* false：有多少个字符需要脱敏就有多少*
     * @return 处理过后的字符串
     */
    public static String masking(String str, int prefix, int suffix, boolean onlyOne){

        //如果字符串为空字符
        if (StringUtils.isBlank(str)){
            return str;
        }

        //字符串长度小于等于需要保留的总位数，直接返回原字符串
        int temp = prefix + suffix;
        int length = StringUtils.length(str);
        if (length <= temp){
            return str;
        }
        StringBuilder builder = new StringBuilder(str.substring(0, prefix));

        int needSize = onlyOne ? 1 : length - temp;
        for (int j = 0; j < needSize; j++) {
            builder.append(DefaultConstant.ASTERISK);
        }
        builder.append(str, length - suffix, length);
        return builder.toString();
    }

    /**
     * 获取字符串中包含的手机号
     * @param str 字符串
     * @return 手机号集合
     */
    public static List<String> getPhoneNum(String str) {

        List<String> result = new ArrayList<>(4);

        if (str == null || str.length() <= 0) {
            return result;
        }

        Matcher matcher = PHONE_PATTERN.matcher(str);
        while (matcher.find()) {
            result.add(matcher.group());
        }

        return result;
    }

    /**
     * 日志打印脱敏手机号 格式：111*1111
     * @param phone 手机号
     * @return 脱敏后的字符串
     */
    public static String maskingPhoneForLog(String phone) {
        return masking(phone, 3, 4, true);
    }

    /**
     * 脱敏手机号 格式：111****1111
     * @param phone 手机号
     * @return 脱敏后的字符串
     */
    public static String maskingPhone(String phone) {
        return masking(phone, 3, 4, false);
    }

    /**
     * 从字符换里边配置出所有的手机号，并把手机号脱敏
     * @param str 需要处理的字符串
     * @param onlyOne 是否只需要一个*脱敏
     * @return 手机号脱敏后的字符串
     */
    public static String maskingAllPhone(String str, boolean onlyOne){
        if (StringUtils.isBlank(str)){
            return str;
        }

        List<String> list = StringUtil.getPhoneNum(str);
        if (CollectionUtils.isEmpty(list)){
            return str;
        }

        for (String s : list) {
            str = str.replaceAll(s, StringUtil.masking(s, 3, 4, onlyOne));
        }

        return str;
    }

    /**
     * 若字符串长度大于maxLength，则修剪
     * @param str 字符串
     * @param maxLength 最大长度
     * @return 前maxLength长度字符串
     */
    public static String subStringIfAbsent(String str, int maxLength) {
        if (str == null || str.isEmpty()) {
            return str;
        }
        if (str.length() <= maxLength) {
            return str;
        }
        return str.substring(0, maxLength);
    }

    /**
     * 逗号分割的数字字符串分割成list
     *
     * @param str 逗号分割的数字字符串
     * @return id list
     */
    public static List<Long> splitParseLong(String str) {
        if (StringUtils.isBlank(str)) {
            return Collections.emptyList();
        }
        String[] ids = str.split(DefaultConstant.DEFAULT_SEPARATION);
        return Arrays.stream(ids).map(StringUtil::parseLong).filter(Objects::nonNull).collect(Collectors.toList());
    }

    /**
     * 字符串转Long
     *
     * @param str 数字字符串
     * @return long
     */
    public static Long parseLong(String str) {
        if (StringUtils.isBlank(str) || !NumberUtils.isNumeric(str)) {
            return null;
        }
        return Long.valueOf(str);
    }
}
